==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WeightedCloseIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.bi = function () {
        return new WeightedCloseIndicator();
    };
    WeightedCloseIndicator.prototype.get_ab8 = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_abz = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/WeightedCloseIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { WeightedCloseIndicatorStrategy } from "./WeightedCloseIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WeightedCloseIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WeightedCloseIndicator, _super);
    function WeightedCloseIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WeightedCloseIndicator.prototype.bj = function () {
        return new WeightedCloseIndicator();
    };
    WeightedCloseIndicator.prototype.get_ach = function () {
        return new WeightedCloseIndicatorStrategy();
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "ach", {
        get: function () {
            return this.get_ach();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.prototype.get_ab8 = function () {
        return WeightedCloseIndicator.$;
    };
    Object.defineProperty(WeightedCloseIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    WeightedCloseIndicator.$t = markType(WeightedCloseIndicator, 'WeightedCloseIndicator', ItemwiseStrategyBasedIndicator.$);
    return WeightedCloseIndicator;
}(ItemwiseStrategyBasedIndicator));
export { WeightedCloseIndicator };
